==> bcrypt-pbkdf-0.6.1.crate: bcrypt-pbkdf-0.6.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.6.1 (2021-05-04)
### Changed
- Bump `blowfish` dependency to v0.8 ([#171])

[#171]: https://github.com/RustCrypto/password-hashing/pull/171

## 0.6.0 (2021-04-29) [YANKED]
### Changed
- Bump `crypto-mac` dependency to v0.11 ([#165])
- Bump `pbkdf2` to v0.8 ([#167])

[#165]: https://github.com/RustCrypto/password-hashing/pull/165
[#167]: https://github.com/RustCrypto/password-hashing/pull/167

## 0.5.0 (2021-01-29)
### Changed
- Bump `pbkdf2` dependency to v0.7 ([#102])

[#102]: https://github.com/RustCrypto/password-hashing/pull/102

## 0.4.0 (2020-10-18)
### Changed
- Bump `crypto-mac` dependency to v0.10 ([#58])
- Bump `pbkdf2` dependency to v0.10 ([#61])

[#61]: https://github.com/RustCrypto/password-hashing/pull/61
[#58]: https://github.com/RustCrypto/password-hashing/pull/58

## 0.3.0 (2020-08-18)
### Changed
- Bump `crypto-mac` dependency to v0.9, `blowfish` to v0.6, and `pbkdf2` to v0.5 ([#46])

[#46]: https://github.com/RustCrypto/password-hashing/pull/46

## 0.2.1 (2020-06-03)
### Added
- `no_std` support ([#41])

[#41]: https://github.com/RustCrypto/password-hashing/pull/41

## 0.2.0 (2020-05-13)
### Changed
- Update dependencies to `sha2 v0.9`, `pbkdf2 v0.4`, `blowfish v0.5`,
and `crypto-mac v0.8`

## 0.1.0 (2020-01-03)
- Initial release

==> bcrypt-pbkdf-0.6.2.crate: bcrypt-pbkdf-0.6.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.6.2 (2021-07-20)
### Changed
- Pin `zeroize` dependency to v1.3 ([#190])

[#190]: https://github.com/RustCrypto/password-hashes/pull/190

## 0.6.1 (2021-05-04)
### Changed
- Bump `blowfish` dependency to v0.8 ([#171])

[#171]: https://github.com/RustCrypto/password-hashing/pull/171

## 0.6.0 (2021-04-29) [YANKED]
### Changed
- Bump `crypto-mac` dependency to v0.11 ([#165])
- Bump `pbkdf2` to v0.8 ([#167])

[#165]: https://github.com/RustCrypto/password-hashing/pull/165
[#167]: https://github.com/RustCrypto/password-hashing/pull/167

## 0.5.0 (2021-01-29)
### Changed
- Bump `pbkdf2` dependency to v0.7 ([#102])

[#102]: https://github.com/RustCrypto/password-hashing/pull/102

## 0.4.0 (2020-10-18)
### Changed
- Bump `crypto-mac` dependency to v0.10 ([#58])
- Bump `pbkdf2` dependency to v0.10 ([#61])

[#61]: https://github.com/RustCrypto/password-hashing/pull/61
[#58]: https://github.com/RustCrypto/password-hashing/pull/58

## 0.3.0 (2020-08-18)
### Changed
- Bump `crypto-mac` dependency to v0.9, `blowfish` to v0.6, and `pbkdf2` to v0.5 ([#46])

[#46]: https://github.com/RustCrypto/password-hashing/pull/46

## 0.2.1 (2020-06-03)
### Added
- `no_std` support ([#41])

[#41]: https://github.com/RustCrypto/password-hashing/pull/41

## 0.2.0 (2020-05-13)
### Changed
- Update dependencies to `sha2 v0.9`, `pbkdf2 v0.4`, `blowfish v0.5`,
and `crypto-mac v0.8`

## 0.1.0 (2020-01-03)
- Initial release
